.. _api-index:

API Reference
=============

.. currentmodule:: gmeterpy.corrections

Gravity Corrections and Reductions
----------------------------------

.. autosummary::
   :toctree: _autosummary

   gmeterpy.corrections.atmosphere
